Attribute VB_Name = "DMcLgLCD"
Option Explicit

' Copyright  2011 Dan Minut, http://www.mangareader.com

' =======================================================
' Simple example project for the DMcLgLCD wrapper for
' Logitech's G-series LCD keyboards.

' =======================================================
' This project contains the bare minimum for opening and
' displaying a monochrome or color picture box to the LCD.
' For more control try the advanced example project.

' A color G-19 keyboard can emulate a monochrome keyboard.
' If you send a LGLCD_DEVICE_BW image to a color device, it
' will switch to emulated mode.  Once you send a
' LGLCD_DEVICE_QVGA image, however, it will henceforth
' remain in color mode and not switch back to emulated mode.

' =======================================================
' The dll is not a com style dll so it does not need to
' be added into references or components.  Simply drop it
' into the same directory as your project.

' WARNING! - if you open the VB6 IDE and then open your
' project, your project directory will not be in your
' path and the dll will not be found.  Either
' double-click your .vbp project from Windows Explorer
' to open it or put the DMcLgLCD.dll someplace in your
' Windows path, such as C:\Windows\System32

' =======================================================
' Free for commercial and non-commercial use.  Please
' include an attribution in your distributed
' documentation and/or help/about pages.

' =======================================================


'Windows Standard Error Contstants
Public Const ERROR_SUCCESS As Long = 0

'LCD Constants
Public Const LGLCD_FORE_YES As Long = 1
Public Const LGLCD_FORE_NO As Long = 0
Public Const LGLCD_DEVICE_BW As Long = 1
Public Const LGLCD_DEVICE_QVGA As Long = 2
Public Const LGLCD_INVALID_DEVICE As Long = -1
Public Const LGLCD_INVALID_CONNECTION As Long = -1

'G-15 Button Constants
Public Const LGLCD_BUTTON_1     As Long = 1
Public Const LGLCD_BUTTON_2     As Long = 2
Public Const LGLCD_BUTTON_3     As Long = 4
Public Const LGLCD_BUTTON_4     As Long = 8

'G-19 Button Constants
Public Const LGLCD_BUTTON_LEFT   As Long = &H100     'Decimal 256
Public Const LGLCD_BUTTON_RIGHT  As Long = &H200     'Decimal 512
Public Const LGLCD_BUTTON_OK     As Long = &H400     'Decimal 1024
Public Const LGLCD_BUTTON_CANCEL As Long = &H800     'Decimal 2048
Public Const LGLCD_BUTTON_UP     As Long = &H1000    'Decimal 4096
Public Const LGLCD_BUTTON_DOWN   As Long = &H2000    'Decimal 8192
Public Const LGLCD_BUTTON_MENU   As Long = &H4000    'Decimal 16384

'Initialization functions.  Must be paired.  Put LcdInit in your main and LcdDeInit in your
'exit function (ie. Form_Unload).
'Returns ERROR_SUCCESS on success, Windows error number if not
Public Declare Function LcdInit Lib "DMcLgLCD.dll" () As Long
Public Declare Function LcdDeInit Lib "DMcLgLCD.dll" () As Long

'Connection functions.  You can connect more than once if you want to have multiple screens on a
'single device.  Disconnection should happen after you close all of your devices.  Best place is just before
'LcdDeInit in your Form_Unload event.
' - appFriendlyName is the name displayed with your LCD screen.  It will also show up in the Logitech Connection Manager.
' - isPersistent is now ignored by the Logitech drivers.  Just send 0.
' - isAutostartable indicates whether you want the Logitech Connection Manager to start your app when Windows starts.  0 for no, 1 for yes.
'Returns connection on success, LGLCD_INVALID_CONNECTION otherwise.
Public Declare Function LcdConnect Lib "DMcLgLCD.dll" Alias "LcdConnectA" (ByVal appFriendlyName As String, ByVal isPersistent As Long, ByVal isAutostartable As Long) As Long
'The only differnce between these two functions is that LcdConnectEx tells the LCD library that your app is capable of dealing with both
'monochrome and color devices.  If you need to get more than just the four basic buttons off of a G-19, you'll need to use this function instead
'of LcdConnect.
Public Declare Function LcdConnectEx Lib "DMcLgLCD.dll" Alias "LcdConnectExA" (ByVal appFriendlyName As String, ByVal isPersistent As Long, ByVal isAutostartable As Long) As Long

' - connection is the return you get from LcdConnect.  Issue a Disconnect for Each Connection when done.
'Returns ERROR_SUCCESS on success, Windows error number otherwise.
Public Declare Function LcdDisconnect Lib "DMcLgLCD.dll" (ByVal connection As Long) As Long


'Open functions.  Opens a device for output.  Issue a LcdClose before disconnecting your connection.  Again, the
'best location is before your LcdDisconnect in your Form_Unload event.
' - connection is the return you get from LcdConnect.
' - deviceType is the type of connection you'd like to make. LGLCD_DEVICE_BW for monochrome and LGLCD_DEVICE_QVGA for color.
' If you specify one or the other, only that type of device will open, leaving those without that device unserviced.
' Best practice is to attempt to open a color device first, then a monochrome device if that fails.  Alternatively, you
' could let the user decide in a configuration setting.  You can send monochrome images to a color device.
'Returns deviceID on success, LGLCD_INVALID_DEVICE otherwise.
Public Declare Function LcdOpenByType Lib "DMcLgLCD.dll" (ByVal connection As Long, ByVal deviceType As Long) As Long
'Returns ERROR_SUCCESS on success, Windows error number otherwise.
Public Declare Function LcdClose Lib "DMcLgLCD.dll" (ByVal device As Long) As Long

'Sends an image to the LCD.
' - device is the return from LcdOpenByType.
' - hBitmap is the image to send.  A PictureBox.Image is in the proper format.  You can also send Windows GDI HBITMAPs as well.
' - format is either LGLCD_DEVICE_BW for monochrome or LGLCD_DEVICE_QVGA for color.  Sending a monochrome image to a color device will
' display in compatibility mode.  Sending a color image to a monochrome device will no display.  Once you send a color image to a color
' device, you can no longer send monochrome images to it until you've closed and reopened the device.
'Returns ERROR_SUCCESS on success, Windows error number otherwise.
Public Declare Function LcdUpdateBitmap Lib "DMcLgLCD.dll" (ByVal device As Long, ByVal hBitmap As Long, ByVal format As Long) As Long

'Sets the LCD app to the forground on the device.  Only works once an LcdUpdateBitmap has been sent to the device for the first time.
' - device is the return from LcdOpenByType.
' - foregroundYesNoFlag is either LCD_FORE_YES or LCD_FORE_NO.
'Returns ERROR_SUCCESS on success, Windows error otherwise.
Public Declare Function LcdSetAsLCDForegroundApp Lib "DMcLgLCD.dll" (ByVal device As Long, ByVal foregroundYesNoFlag As Long) As Long

'Reads the LCD Button state at the time of the call.  Needs to be in a polling loop to catch a button press.
'device will be the type of device (LGLCD_DEVICE_BW or LGLCD_DEVICE_QVGA).  Returns OR'd button state as follows:
' Button 1 or left  = 1
' Button 2 or right = 2
' Button 3 or up    = 4
' Button 4 or down  = 8
'You'll need to AND with a mask to see if a particular button is pressed.  Ie. if (Buttons and 8) = 8 then <button 4 code>
Public Declare Function LcdReadSoftButtons Lib "DMcLgLCD.dll" (ByVal device As Long) As Long

'Initializes the configuration callback process.  This is called when the user clicks the configure button in the Logitech LCD Manager.
'To use, set up a Sub with one argument: (ByVal device As Long)
'device with be the device number received from LcdOpenByType.
'LcdSetConfigCallback can be used any time after LcdOpenByType.
'Returns ERROR_SUCCESS on success, Windows error number otherwise.
Public Declare Function LcdSetConfigCallback Lib "DMcLgLCD.dll" (ByVal configCallback As Long) As Long


'Simplified open and close functions.  Can only deal with a single device at a time.

' - appFriendlyName is the name displayed with your LCD screen.  It will also show up in the Logitech Connection Manager.
' - deviceType is a long variable provided to the function.  It's value will be replace with either LGLCD_DEVICE_BW or LGLCD_DEVICE_QVGA depending on what device got opened.
'Returns deviceID on success, LGLCD_INVALID_DEVICE otherwise.
Public Declare Function LcdSimpleOpen Lib "DMcLgLCD.dll" Alias "LcdSimpleOpenA" (ByVal appFriendlyName As String, ByRef deviceType As Long) As Long
'Returns ERROR_SUCCESS on success, Windows error otherwise.
Public Declare Function LcdSimpleClose Lib "DMcLgLCD.dll" () As Long


Global LCDEnabled As Boolean
Global LCDButtons As Long
Global ConfigureFlag As Long




' returns LGLCD_INVALID_CONNECTION or connection type if successful
Public Function LCDOpen(ByVal appFriendlyName As String, ByRef LCDconnection As Long, ByRef LCDdevice As Long)
    Dim result As Long
    
    result = LcdInit
    
    If result = ERROR_SUCCESS Then
        LCDconnection = LcdConnectEx(appFriendlyName, 0, 0)
        If LCDconnection <> LGLCD_INVALID_CONNECTION Then
            LCDdevice = LcdOpenByType(LCDconnection, LGLCD_DEVICE_QVGA)
            If LCDdevice = LGLCD_INVALID_DEVICE Then
                LCDdevice = LcdOpenByType(LCDconnection, LGLCD_DEVICE_BW)
                If LCDdevice = LGLCD_INVALID_DEVICE Then
                    LCDOpen = LCDdevice
                Else
                    LCDOpen = LGLCD_DEVICE_BW
                End If
            Else
                LCDOpen = LGLCD_DEVICE_QVGA
            End If
            
        Else
            LCDOpen = LCDconnection
        End If
    Else
        LCDOpen = result
    End If

End Function



'This is the callback from the LCD library that tells your program that the user clicked the Configure
'button from the Logitech LCD Manager.  Because it's a callback, you can't open forms or do much at all,
'so stick to setting flags that you can read somewhere else.  In this example, I used my existing timer from
'the button reading routine.
Public Sub configurationHandler(ByVal device As Long)

    'As you can have multiple devices open simultaneously, this allows you to determine which device is being configured.
    'If you only have a single device, you can test for > 0 as I have in this example.
    ConfigureFlag = device
    
End Sub


Public Sub drawNumberedCircle(pic As PictureBox, x As Long, y As Long, r As Long, txt As String, color As ColorConstants)
Dim savedColor As Long
    Dim xOff As Integer, yOff As Integer
    savedColor = pic.ForeColor

    pic.ForeColor = color
    pic.Circle (x, y), r
    
    xOff = pic.FontSize * Len(txt) / 2
    yOff = pic.FontSize / 1.5
    pic.CurrentX = x - xOff
    pic.CurrentY = y - yOff
    pic.Print txt
    
    pic.ForeColor = savedColor


End Sub
